<?php

namespace Drupal\file_mime_validator;

/**
 * Provides various file types.
 */
class FileTypes {

  private const FILETYPES = [
    'text' => [
      'text/',
      'text/plain',
      'text/vnd.in3d.3dml',
      'text/x-c++src',
      'text/x-perl',
      'text/x-adasrc',
      'text/cache-manifest',
      'text/x-common-lisp',
      'text/x-asm',
      'text/x-ssa',
      'text/x-systemd-unit',
      'text/x-bibtex',
      'text/x-c',
      'text/x-csrc',
      'text/x-cobol',
      'text/x-opencl-src',
      'text/x-tex',
      'text/x-cmake',
      'text/coffeescript',
      'text/crystal',
      'text/x-crystal',
      'text/x-csharp',
      'text/css',
      'text/csv',
      'application/csv',
      'application/vnd',
      'application/pdf',
      'application/rtf',
      'application/msword',
      'message/rfc822',
      'text/x-comma-separated-values',
      'text/x-csv',
      'text/csv-schema',
      'text/vnd.curl',
      'text/x-dart',
      'text/x-dcl',
      'text/vnd.curl.dcurl',
      'text/x-diff',
      'text/x-patch',
      'text/vnd.graphviz',
      'text/prs.lines.tag',
      'text/x-dsl',
      'text/x-dtd',
      'text/x-eiffel',
      'text/x-emacs-lisp',
      'text/xml-external-parsed-entity',
      'text/x-erlang',
      'text/ecmascript',
      'text/x-setext',
      'text/x-elixir',
      'text/x-fortran',
      'text/x-gherkin',
      'text/vnd.fmi.flexstor',
      'text/vnd.fly',
      'text/x-xslfo',
      'text/x.gcode',
      'text/directory',
      'text/vcard',
      'text/x-vcard',
      'text/gedcom',
      'text/x-go',
      'text/x-gradle',
      'text/x-groovy',
      'text/x-genie',
      'text/google-video-pointer',
      'text/x-google-video-pointer',
      'text/x-chdr',
      'text/x-c++hdr',
      'text/x-handlebars-template',
      'text/x-component',
      'text/x-haskell',
      'text/html',
      'text/slim',
      'text/spreadsheet',
      'text/stylus',
      'text/vnd.dvb.subtitle',
      'text/x-microdvd',
      'text/x-mpsub',
      'text/x-subviewer',
      'text/x-svsrc',
      'text/x-svhdr',
      'text/troff',
      'text/x-troff',
      'text/x-troff-me',
      'text/x-txt2tags',
      'text/x-texinfo',
      'text/ico',
      'text/calendar',
      'text/x-vcalendar',
      'text/x-idl',
      'text/x-kotlin',
      'text/x-ldif',
      'text/less',
      'text/x-literate-haskell',
      'text/x-log',
      'text/x-lua',
      'text/x-lilypond',
      'text/x-lyx',
      'text/x-matlab',
      'text/x-objcsrc',
      'text/x-octave',
      'text/x-makefile',
      'text/markdown',
      'text/x-markdown',
      'text/vnd.senx.warpscript',
      'text/vnd.curl.mcurl',
      'text/mdx',
      'text/javascript',
      'text/x-ocaml',
      'text/x-troff-mm',
      'text/mathml',
      'text/x-modelica',
      'text/x-moc',
      'text/x-mof',
      'text/x-mrml',
      'text/x-troff-ms',
      'text/tcl',
      'text/x-tcl',
      'text/vnd.qt.linguist',
      'text/vnd.trolltech.linguist',
      'text/tab-separated-values',
      'text/turtle',
      'text/x-twig',
      'text/x-uil',
      'text/uri-list',
      'text/x-uuencode',
      'text/x-imelody',
      'text/x-kaitai-struct',
      'text/x-mup',
      'text/n3',
      'text/x-nfo',
      'text/x-ocl',
      'text/x-ooc',
      'text/x-opml',
      'text/x-opml+xml',
      'text/org',
      'text/x-org',
      'text/rdf',
      'text/x-pascal',
      'text/x-processing',
      'text/x-gettext-translation',
      'text/x-po',
      'text/x-gettext-translation-template',
      'text/x-pot',
      'text/x-python',
      'text/x-python3',
      'text/x-qml',
      'text/x-iptables',
      'text/vnd.sun.j2me.app-descriptor',
      'text/jade',
      'text/x-java',
      'text/x-java-source',
      'text/jsx',
      'text/x-reject',
      'text/x-ms-regedit',
      'text/xml',
      'text/rust',
      'text/rss',
      'text/x-rst',
      'text/vnd.rn-realtext',
      'text/rtf',
      'text/richtext',
      'text/x-sagemath',
      'text/x-sass',
      'text/x-scala',
      'text/x-scheme',
      'text/x-scss',
      'text/vnd.curl.scurl',
      'text/x-dbus-service',
      'text/x-sfv',
      'text/sgml',
      'text/x-sh',
      'text/shex',
      'text/spdx',
      'text/x-rpm-spec',
      'text/vnd.in3d.spot',
      'text/x-sql',
      'text/x-vala',
      'text/x-verilog',
      'text/vbs',
      'text/vbscript',
      'text/x-vhdl',
    ],
    'image' => [
      'image/',
      'image/cgm',
      'image/cdr',
      'image/x-cmx',
      'image/x-cdr',
      'image/avif',
      'image/astc',
      'image/apng',
      'image/bmp',
      'image/x-bmp',
      'image/x-ms-bmp',
      'image/x-3ds',
      'image/prs.btif',
      'image/x-sony-arw',
      'image/x-canon-crw',
      'image/x-canon-cr2',
      'image/x-canon-cr3',
      'image/vnd.pco.b16',
      'image/avif-sequence',
      'image/x-kodak-dcr',
      'image/x-applix-graphics',
      'image/x-win-bitmap',
      'image/vnd.ms-dds',
      'image/x-dds',
      'image/vnd.djvu',
      'image/vnd.djvu+multipage',
      'image/x-djvu',
      'image/x.djvu',
      'image/x-adobe-dng',
      'image/dicom-rle',
      'image/vnd.dxf',
      'image/vnd.dwg',
      'image/emf',
      'image/x-emf',
      'image/x-eps',
      'image/x-bzeps',
      'image/x-gzeps',
      'image/aces',
      'image/x-exr',
      'image/vnd.fastbidsheet',
      'image/x-freehand',
      'image/x-xfig',
      'image/fits',
      'image/x-fits',
      'image/vnd.fpx',
      'image/vnd.fst',
      'image/fax-g3',
      'image/g3fax',
      'image/x-gimp-gbr',
      'image/x-gimp-gih',
      'image/gif',
      'image/heic',
      'image/heif',
      'image/heic-sequence',
      'image/heif-sequence',
      'image/hej2k',
      'image/hsj2',
      'image/targa',
      'image/tga',
      'image/x-icb',
      'image/x-targa',
      'image/x-tga',
      'image/x-icns',
      'image/ico',
      'image/icon',
      'image/vnd.microsoft.icon',
      'image/x-ico',
      'image/x-icon',
      'image/ief',
      'image/x-iff',
      'image/x-ilbm',
      'image/x-jp2-codestream',
      'image/jphc',
      'image/jls',
      'image/x-jng',
      'image/jp2',
      'image/jpeg2000',
      'image/jpeg2000-image',
      'image/x-jpeg2000-image',
      'image/x-xwindowdump',
      'image/x-xpixmap',
      'image/x-xpm',
      'image/vnd.xiff',
      'image/x-compressed-xcf',
      'image/x-xcf',
      'image/x-xbitmap',
      'image/x-sigma-x3f',
      'image/wmf',
      'image/x-win-metafile',
      'image/x-wmf',
      'image/webp',
      'image/vnd.ms-photo',
      'image/vnd.wap.wbmp',
      'image/vnd.valve.source.texture',
      'image/vnd.dece.graphic',
      'image/tiff',
      'image/tiff-fx',
      'image/vnd.tencent.tap',
      'image/t38',
      'image/svg',
      'image/x-sony-srf',
      'image/x-sony-sr2',
      'image/svg+xml',
      'image/x-sun-raster',
      'image/vnd.dvb.subtitle',
      'image/svg+xml-compressed',
      'image/x-skencil',
      'image/x-mrsid-image',
      'image/sgi',
      'image/x-sgi',
      'image/x-panasonic-raw2',
      'image/x-panasonic-rw2',
      'image/vnd.rn-realpix',
      'image/rle',
      'image/vnd.fujixerox.edmics-rlc',
      'image/x-rgb',
      'image/x-cmu-raster',
      'image/x-panasonic-raw',
      'image/x-panasonic-rw',
      'image/x-fuji-raf',
      'image/x-quicktime',
      'image/prs.pti',
      'image/photoshop',
      'image/psd',
      'image/vnd.adobe.photoshop',
      'image/x-photoshop',
      'image/x-psd',
      'image/x-portable-pixmap',
      'image/x-macpaint',
      'image/png',
      'image/x-pict',
      'image/x-portable-graymap',
      'image/x-pentax-pef',
      'image/pdf',
      'image/x-pcx',
      'image/vnd.zbrush.pcx',
      'image/x-photo-cd',
      'image/x-portable-bitmap',
      'image/x-gimp-pat',
      'image/openraster',
      'image/x-olympus-orf',
      'image/x-nikon-nrw',
      'image/vnd.net-fpx',
      'image/x-nikon-nef',
      'image/x-msod',
      'image/x-minolta-mrw',
      'image/vnd.fujixerox.edmics-mmr',
      'image/vnd.ms-modi',
      'image/x-lwo',
      'image/x-lws',
      'image/ktx',
      'image/ktx2',
      'image/x-kodak-kdc',
      'image/jxl',
      'image/jxr',
      'image/jxra',
      'image/jxrs',
      'image/jxs',
      'image/jxsc',
      'image/jxsi',
      'image/jxss',
      'image/x-kodak-k25',
      'image/jpx',
      'image/jpeg',
      'image/pjpeg',
      'image/jpm',
      'image/jph',
      'image/vnd.airzip.accelerator.azv',
      'application/vnd.appimage',
      'application/x-iso9660-appimage',
    ],
    'audio' => [
      'audio/',
      'audio/3gpp',
      'audio/3gpp2',
      'audio/vnd.audible',
      'audio/x-rn-3gpp-amr',
      'audio/3gpp-encrypted',
      'audio/x-rn-3gpp-amr-wb',
      'audio/x-pn-audibleaudio',
      'audio/x-rn-3gpp-amr-encrypted',
      'audio/x-rn-3gpp-amr-wb-encrypted',
      'application/vnd.yamaha.smaf-audio',
    ],
    'video' => [
      'video/',
      'video/3gp',
      'video/3gpp',
      'video/mp2t',
      'video/3gpp2',
      'video/x-anim',
      'video/x-ms-wm',
      'video/x-ms-asf',
      'video/x-ms-wax',
      'video/x-ms-wmx',
      'video/x-ms-wvx',
      'video/avi',
      'video/divx',
      'video/x-avi',
      'video/x-mpeg',
      'video/x-mpeg2',
      'video/mpeg-system',
      'video/x-mpeg-system',
      'video/annodex',
      'video/msvideo',
      'video/vnd.divx',
      'video/x-annodex',
      'video/x-msvideo',
      'video/vnd.dvb.file',
      'video/3gpp-encrypted',
      'video/x-ms-asf-plugin',
      'video/vnd.radgamettools.bink',
      'video/dv',
      'video/mp4',
      'video/mp4v-es',
      'video/x-f4v',
      'video/x-m4v',
      'video/fli',
      'video/x-fli',
      'video/x-flic',
      'video/h261',
      'video/h263',
      'video/h264',
      'video/jpm',
      'video/jpeg',
      'video/vnd.mpegurl',
      'video/x-mpegurl',
      'video/mpeg',
      'video/vnd.dece.mobile',
      'video/vnd.dece.sd',
      'video/vnd.uvvu.mp4',
      'video/vnd.dece.video',
      'video/vnd.dece.hd',
      'video/quicktime',
      'video/x-real-video',
      'video/vnd.rn-realvideo',
      'video/vnd.radgamettools.smacker',
      'video/vnd.ms-playready.media.pyv',
    ],
    'compression' => [
      'application/zip',
      'application/x-rar',
      'application/x-zip',
      'application/vnd.rar',
      'application/epub+zip',
      'application/x-compress',
      'application/x-7z-compressed',
      'application/x-zip-compressed',
      'application/x-ace-compressed',
      'application/x-cfs-compressed',
      'application/x-cpio-compressed',
      'application/x-compressed-iso',
      'application/x-dgc-compressed',
      'application/x-gca-compressed',
      'application/x-lzh-compressed',
      'application/x-rar-compressed',
      'application/x-compressed-tar',
      'application/x-xz-compressed-tar',
      'application/x-zip-compressed-fb2',
      'application/x-bzip-compressed-tar',
      'application/x-lzip-compressed-tar',
      'application/x-lz4-compressed-tar',
      'application/vnd.ms-cab-compressed',
      'application/x-lzma-compressed-tar',
      'application/x-zstd-compressed-tar',
      'application/x-lrzip-compressed-tar',
      'application/x-raw-disk-image-xz-compressed',
    ],
  ];

  /**
   * Check  for Parent File Type.
   *
   * @param string $mime
   *   Mime Type.
   *
   * @return string
   *   Returns parent type, if found.
   */
  public function getFileType(string $mime) {
    $return = "no file type found";
    foreach (static::FILETYPES as $key => $mimeTypes) {
      if (in_array($mime, $mimeTypes)) {
        $return = $key;
      }
    }
    return $return;
  }

}
